@@ -18,33 +18,13 @@ def sir_metapop_example():
 
     events = np.array(
         [
-            [
-                [11.0, 11.0],
-                [11.0, 6.0],
-                [2.0, 6.0],
-                [10.0, 6.0],
-                [12.0, 7.0],
-                [11.0, 5.0],
-                [13.0, 10.0],
-            ],
-            [
-                [5.0, 4.0],
-                [5.0, 2.0],
-                [11.0, 1.0],
-                [8.0, 4.0],
-                [7.0, 4.0],
-                [5.0, 5.0],
-                [12.0, 6.0],
-            ],
-            [
-                [2.0, 2.0],
-                [4.0, 2.0],
-                [1.0, 0.0],
-                [2.0, 2.0],
-                [6.0, 1.0],
-                [4.0, 1.0],
-                [6.0, 1.0],
-            ],
+            [[11.0, 11.0], [5.0, 4.0], [2.0, 2.0]],
+            [[11.0, 6.0], [5.0, 2.0], [4.0, 2.0]],
+            [[2.0, 6.0], [11.0, 1.0], [1.0, 0.0]],
+            [[10.0, 6.0], [8.0, 4.0], [2.0, 2.0]],
+            [[12.0, 7.0], [7.0, 4.0], [6.0, 1.0]],
+            [[11.0, 5.0], [5.0, 5.0], [4.0, 1.0]],
+            [[13.0, 10.0], [12.0, 6.0], [6.0, 1.0]],
         ],
         dtype=np.float32,
     )
