@@ -2,7 +2,10 @@
 
 # ruff: noqa: F401,F811
 
+import jax
 import numpy as np
+import pytest
+import tensorflow_probability.substrates.jax as tfp
 
 from .fixtures import sir_metapop_example
 from .left_censored_events_proposal import (
@@ -10,7 +13,12 @@ from .left_censored_events_proposal import (
 )
 
 
-def test_initial_conditions_event_time_proposal(sir_metapop_example):
+@pytest.fixture
+def seed():
+    return jax.random.key(42)
+
+
+def test_initial_conditions_event_time_proposal(sir_metapop_example, seed):
     proposer = left_censored_event_time_proposal(
         events=sir_metapop_example["events"],
         initial_state=sir_metapop_example["initial_conditions"],
@@ -21,13 +29,14 @@ def test_initial_conditions_event_time_proposal(sir_metapop_example):
         max_events=5,
     )
 
-    for _ in range(100):
-        proposal = proposer.sample()
+    seeds = jax.random.split(seed, num=100)
+    for s in seeds:
+        proposal = proposer.sample(seed=s)
 
-    assert proposal["unit"].shape == (1,)
-    assert proposal["timepoint"].shape == (1,)
-    assert proposal["direction"].shape == ()
-    assert proposal["num_events"].shape == (1,)
+        assert proposal["unit"].shape == (1,)
+        assert proposal["timepoint"].shape == (1,)
+        assert proposal["direction"].shape == (1,)
+        assert proposal["num_events"].shape == (1,)
 
     logp = proposer.log_prob(proposal)
     assert logp
